#!/usr/bin/env python
# jet.py

"""
Author : peters 

Revision History:
File created on 06 Sep 2010.

"""

import sys
import os
import logging
import subprocess

from da.baseclasses.platform import PlatForm

std_joboptions={'jobname':'test','jobaccount':'co2','jobnodes':'nserial 1','jobshell':'/bin/sh','depends':'','jobtime':'00:30:00'}

class JetPlatForm(PlatForm):
    def __init__(self):
        self.Identifier     = 'NOAA jet'    # the identifier gives the platform name
        self.Version        = '1.0'     # the platform version used

        msg1  = '%s platform object initialized'%self.Identifier ; logging.debug(msg1)
        msg2  = '%s version: %s'%(self.Identifier,self.Version) ; logging.debug(msg2)


    def GetJobTemplate(self,joboptions={}):
        """ Return the job template for a given computing system, and fill it with options from the dictionary provided as argument"""

        template = """#$ -N jobname \n"""+ \
                   """#$ -A jobaccount \n"""+ \
                   """#$ -pe jobnodes \n"""+ \
                   """#$ -l h_rt=jobtime \n"""+ \
                   """#$ -S jobshell \n"""+ \
                   """#$ -cwd \n"""+ \
                   """#$ -r y \n"""+ \
                   """#$ -j y \n"""

        if 'depends' in joboptions:
            template += """#$ -hold_jid depends \n"""

        # First replace from passed dictionary
        for k,v in joboptions.iteritems():
            while k in template:
                template = template.replace(k,v)

        # Fill remaining values with std_options
        for k,v in std_joboptions.iteritems():
            while k in template:
                template = template.replace(k,v)

        return template

    def GetMyID(self):
        try:
            return os.environ['JOB_ID']
        except:
            return os.getpid()

    def UnsuspendCommand(self):
        return 'qmod -usj %s'%(self.GetMyID())

    def SuspendJob(self):
        """ Method suspends the running job"""

        cmd     = ['qmod','-sj',self.GetMyID()]
        output   = subprocess.call(cmd)


    def SubmitJob(self,jobfile,method='qsub'):                   
        """ This method submits a jobfile to the queue, and returns the queue ID """
        
        cmd     = [method,jobfile]
        output  = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]  ; logging.info(output)
        jobid   = output.split()[2]

        return jobid

    def KillJob(self,jobid):                   
        """ This method kills a running job """
        
        output = subprocess.Popen(['qdel',jobid], stdout=subprocess.PIPE).communicate()[0]  ; logging.info(output)

        return output

    def StatJob(self,jobid):                   
        """ This method gets the status of a running job """
        import subprocess
        
        #output = subprocess.Popen(['sgestat'], stdout=subprocess.PIPE).communicate()[0]  ; logging.info(output)

        return ''

if __name__ == "__main__":
    pass
